From b81ab4f9a4c7a50c87eadbd9a33625e6f27a5f2d Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 2 Nov 2019 10:39:51 +0000
Subject: [PATCH 1/5] Posted order is now arrival order

---
 mod/network.php | 38 +++++++++++++++++++-------------------
 1 file changed, 19 insertions(+), 19 deletions(-)

diff --git a/mod/network.php b/mod/network.php
index 64f5cf505f..0942872ed4 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -91,7 +91,7 @@ function network_init(App $a)
 
 			$tab_baseurls = [
 				'',     //all
-				'',     //postord
+				'',     //arrivalord
 				'',     //conv
 				'/new', //new
 				'',     //starred
@@ -99,9 +99,9 @@ function network_init(App $a)
 			];
 			$tab_args = [
 				'order=comment', //all
-				'order=post',    //postord
+				'order=arrival', //arrivalord
 				'conv=1',        //conv
-				'',                 //new
+				'',              //new
 				'star=1',        //starred
 				'bmark=1',       //bookmarked
 			];
@@ -153,14 +153,14 @@ function network_init(App $a)
  * urls -> returns
  *        '/network'                    => $no_active = 'active'
  *        '/network?order=comment'    => $comment_active = 'active'
- *        '/network?order=post'    => $postord_active = 'active'
+ *        '/network?order=arrival'    => $arrivalord_active = 'active'
  *        '/network?conv=1',        => $conv_active = 'active'
  *        '/network/new',                => $new_active = 'active'
  *        '/network?star=1',        => $starred_active = 'active'
  *        '/network?bmark=1',        => $bookmarked_active = 'active'
  *
  * @param App $a
- * @return array ($no_active, $comment_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active);
+ * @return array ($no_active, $comment_active, $arrivalord_active, $conv_active, $new_active, $starred_active, $bookmarked_active);
  */
 function network_query_get_sel_tab(App $a)
 {
@@ -170,7 +170,7 @@ function network_query_get_sel_tab(App $a)
 	$bookmarked_active = '';
 	$all_active = '';
 	$conv_active = '';
-	$postord_active = '';
+	$arrivalord_active = '';
 
 	if (($a->argc > 1 && $a->argv[1] === 'new') || ($a->argc > 2 && $a->argv[2] === 'new')) {
 		$new_active = 'active';
@@ -194,12 +194,12 @@ function network_query_get_sel_tab(App $a)
 
 	if ($no_active == 'active' && !empty($_GET['order'])) {
 		switch($_GET['order']) {
-			case 'post'    : $postord_active = 'active'; $no_active=''; break;
+			case 'arrival' : $arrivalord_active = 'active'; $no_active=''; break;
 			case 'comment' : $all_active     = 'active'; $no_active=''; break;
 		}
 	}
 
-	return [$no_active, $all_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active];
+	return [$no_active, $all_active, $arrivalord_active, $conv_active, $new_active, $starred_active, $bookmarked_active];
 }
 
 function network_query_get_sel_group(App $a)
@@ -475,7 +475,7 @@ function networkThreadedView(App $a, $update, $parent)
 					$datequery2 = Strings::escapeHtml($a->argv[$x]);
 				} else {
 					$datequery = Strings::escapeHtml($a->argv[$x]);
-					$_GET['order'] = 'post';
+					$_GET['order'] = 'arrival';
 				}
 			} elseif (intval($a->argv[$x])) {
 				$gid = intval($a->argv[$x]);
@@ -671,14 +671,14 @@ function networkThreadedView(App $a, $update, $parent)
 	}
 
 	// Normal conversation view
-	if ($order === 'post') {
+	if ($order === 'arrival') {
 		$ordering = '`received`';
 		$order_mode = 'received';
 	} else {
 		$ordering = '`commented`';
 		$order_mode = 'commented';
 	}
-
+Logger::info('Arrival order', ['ordering' => $ordering]);
 	$sql_order = "$sql_table.$ordering";
 
 	if (!empty($_GET['offset'])) {
@@ -738,7 +738,7 @@ function networkThreadedView(App $a, $update, $parent)
 			if (Config::get("system", "like_no_comment")) {
 				$sql_extra4 .= " AND `item`.`gravity` IN (" . GRAVITY_PARENT . "," . GRAVITY_COMMENT . ")";
 			}
-			if ($order === 'post') {
+			if ($order === 'arrival') {
 				// Only show toplevel posts when updating posts in this order mode
 				$sql_extra4 .= " AND `item`.`id` = `item`.`parent`";
 			}
@@ -913,7 +913,7 @@ function network_tabs(App $a)
 	// item filter tabs
 	/// @TODO fix this logic, reduce duplication
 	/// $a->page['content'] .= '<div class="tabs-wrapper">';
-	list($no_active, $all_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active) = network_query_get_sel_tab($a);
+	list($no_active, $all_active, $arrival_active, $conv_active, $new_active, $starred_active, $bookmarked_active) = network_query_get_sel_tab($a);
 
 	// if no tabs are selected, defaults to comments
 	if ($no_active == 'active') {
@@ -933,11 +933,11 @@ function network_tabs(App $a)
 			'accesskey' => 'e',
 		],
 		[
-			'label'	=> L10n::t('Posted Order'),
-			'url'	=> str_replace('/new', '', $cmd) . '?order=post' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
-			'sel'	=> $postord_active,
-			'title'	=> L10n::t('Sort by Post Date'),
-			'id'	=> 'posted-order-tab',
+			'label'	=> L10n::t('Arrival Order'),
+			'url'	=> str_replace('/new', '', $cmd) . '?order=arrival' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
+			'sel'	=> $arrival_active,
+			'title'	=> L10n::t('Sort by arrival date'),
+			'id'	=> 'arrival-order-tab',
 			'accesskey' => 't',
 		],
 	];
@@ -985,7 +985,7 @@ function network_tabs(App $a)
 	// save selected tab, but only if not in file mode
 	if (empty($_GET['file'])) {
 		PConfig::set(local_user(), 'network.view', 'tab.selected', [
-			$all_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active
+			$all_active, $arrival_active, $conv_active, $new_active, $starred_active, $bookmarked_active
 		]);
 	}
 

From 01142cb4d0fe914bcb7ef0075679dd6f285acec5 Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 2 Nov 2019 11:17:47 +0000
Subject: [PATCH 2/5] Remove debug logging

---
 mod/network.php | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/mod/network.php b/mod/network.php
index 0942872ed4..4f795079b5 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -678,7 +678,7 @@ function networkThreadedView(App $a, $update, $parent)
 		$ordering = '`commented`';
 		$order_mode = 'commented';
 	}
-Logger::info('Arrival order', ['ordering' => $ordering]);
+
 	$sql_order = "$sql_table.$ordering";
 
 	if (!empty($_GET['offset'])) {

From 6e11419e00e92efea46637f7eb598f1c60f14e5c Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 2 Nov 2019 12:59:57 +0000
Subject: [PATCH 4/5] Aligned code

---
 mod/network.php | 22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)

diff --git a/mod/network.php b/mod/network.php
index 7ed4827585..80706705dd 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -99,11 +99,11 @@ function network_init(App $a)
 			];
 			$tab_args = [
 				'order=activity', //all
-				'order=post', //postord
-				'conv=1',        //conv
-				'',              //new
-				'star=1',        //starred
-				'bmark=1',       //bookmarked
+				'order=post',     //postord
+				'conv=1',         //conv
+				'',               //new
+				'star=1',         //starred
+				'bmark=1',        //bookmarked
 			];
 
 			$k = array_search('active', $last_sel_tabs);
@@ -151,13 +151,13 @@ function network_init(App $a)
  * Return selected tab from query
  *
  * urls -> returns
- *        '/network'                    => $no_active = 'active'
- *        '/network?order=activity'    => $activity_active = 'active'
- *        '/network?order=post'    => $postord_active = 'active'
+ *        '/network'                => $no_active = 'active'
+ *        '/network?order=activity' => $activity_active = 'active'
+ *        '/network?order=post'     => $postord_active = 'active'
  *        '/network?conv=1',        => $conv_active = 'active'
- *        '/network/new',                => $new_active = 'active'
+ *        '/network/new',           => $new_active = 'active'
  *        '/network?star=1',        => $starred_active = 'active'
- *        '/network?bmark=1',        => $bookmarked_active = 'active'
+ *        '/network?bmark=1',       => $bookmarked_active = 'active'
  *
  * @param App $a
  * @return array ($no_active, $activity_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active);
@@ -194,7 +194,7 @@ function network_query_get_sel_tab(App $a)
 
 	if ($no_active == 'active' && !empty($_GET['order'])) {
 		switch($_GET['order']) {
-			case 'post' : $postord_active = 'active'; $no_active=''; break;
+			case 'post' :     $postord_active = 'active'; $no_active=''; break;
 			case 'activity' : $all_active     = 'active'; $no_active=''; break;
 		}
 	}

From 682001ab0a241160feb4e2b7511e208f64eddf88 Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 2 Nov 2019 13:55:55 +0000
Subject: [PATCH 5/5] And some other renaming

---
 mod/network.php | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/mod/network.php b/mod/network.php
index 80706705dd..124c598877 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -925,10 +925,10 @@ function network_tabs(App $a)
 	// tabs
 	$tabs = [
 		[
-			'label'	=> L10n::t('Latest Activities'),
+			'label'	=> L10n::t('Latest Activity'),
 			'url'	=> str_replace('/new', '', $cmd) . '?order=activity' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
 			'sel'	=> $all_active,
-			'title'	=> L10n::t('Sort by activity Date'),
+			'title'	=> L10n::t('Sort by lastest activity on the posts'),
 			'id'	=> 'activity-order-tab',
 			'accesskey' => 'e',
 		],
@@ -936,7 +936,7 @@ function network_tabs(App $a)
 			'label'	=> L10n::t('Latest Posts'),
 			'url'	=> str_replace('/new', '', $cmd) . '?order=post' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
 			'sel'	=> $post_active,
-			'title'	=> L10n::t('Sort by post date'),
+			'title'	=> L10n::t("Sort by the posts' receiving date"),
 			'id'	=> 'post-order-tab',
 			'accesskey' => 't',
 		],
From f97de526947e709004c0fc31e37c194ca01d0045 Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 2 Nov 2019 12:54:26 +0000
Subject: [PATCH 3/5] Renamed labels

---
 mod/network.php | 54 ++++++++++++++++++++++++-------------------------
 1 file changed, 27 insertions(+), 27 deletions(-)

diff --git a/mod/network.php b/mod/network.php
index 4f795079b5..7ed4827585 100644
--- a/mod/network.php
+++ b/mod/network.php
@@ -86,20 +86,20 @@ function network_init(App $a)
 
 		if ($remember_tab) {
 			// redirect if current selected tab is '/network' and
 			// last selected tab is _not_ '/network?order=comment'.
 			// and this isn't a date query
 
 			$tab_baseurls = [
 				'',     //all
-				'',     //arrivalord
+				'',     //postord
 				'',     //conv
 				'/new', //new
 				'',     //starred
 				'',     //bookmarked
 			];
 			$tab_args = [
-				'order=comment', //all
-				'order=arrival', //arrivalord
+				'order=activity', //all
+				'order=post', //postord
 				'conv=1',        //conv
 				'',              //new
 				'star=1',        //starred
@@ -152,15 +152,15 @@ function network_init(App $a)
  *
  * urls -> returns
  *        '/network'                    => $no_active = 'active'
- *        '/network?order=comment'    => $comment_active = 'active'
- *        '/network?order=arrival'    => $arrivalord_active = 'active'
+ *        '/network?order=activity'    => $activity_active = 'active'
+ *        '/network?order=post'    => $postord_active = 'active'
  *        '/network?conv=1',        => $conv_active = 'active'
  *        '/network/new',                => $new_active = 'active'
  *        '/network?star=1',        => $starred_active = 'active'
  *        '/network?bmark=1',        => $bookmarked_active = 'active'
  *
  * @param App $a
- * @return array ($no_active, $comment_active, $arrivalord_active, $conv_active, $new_active, $starred_active, $bookmarked_active);
+ * @return array ($no_active, $activity_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active);
  */
 function network_query_get_sel_tab(App $a)
 {
@@ -170,7 +170,7 @@ function network_query_get_sel_tab(App $a)
 	$bookmarked_active = '';
 	$all_active = '';
 	$conv_active = '';
-	$arrivalord_active = '';
+	$postord_active = '';
 
 	if (($a->argc > 1 && $a->argv[1] === 'new') || ($a->argc > 2 && $a->argv[2] === 'new')) {
 		$new_active = 'active';
@@ -194,12 +194,12 @@ function network_query_get_sel_tab(App $a)
 
 	if ($no_active == 'active' && !empty($_GET['order'])) {
 		switch($_GET['order']) {
-			case 'arrival' : $arrivalord_active = 'active'; $no_active=''; break;
-			case 'comment' : $all_active     = 'active'; $no_active=''; break;
+			case 'post' : $postord_active = 'active'; $no_active=''; break;
+			case 'activity' : $all_active     = 'active'; $no_active=''; break;
 		}
 	}
 
-	return [$no_active, $all_active, $arrivalord_active, $conv_active, $new_active, $starred_active, $bookmarked_active];
+	return [$no_active, $all_active, $postord_active, $conv_active, $new_active, $starred_active, $bookmarked_active];
 }
 
 function network_query_get_sel_group(App $a)
@@ -475,7 +475,7 @@ function networkThreadedView(App $a, $update, $parent)
 					$datequery2 = Strings::escapeHtml($a->argv[$x]);
 				} else {
 					$datequery = Strings::escapeHtml($a->argv[$x]);
-					$_GET['order'] = 'arrival';
+					$_GET['order'] = 'post';
 				}
 			} elseif (intval($a->argv[$x])) {
 				$gid = intval($a->argv[$x]);
@@ -490,7 +490,7 @@ function networkThreadedView(App $a, $update, $parent)
 	$star  = intval($_GET['star']  ?? 0);
 	$bmark = intval($_GET['bmark'] ?? 0);
 	$conv  = intval($_GET['conv']  ?? 0);
-	$order = Strings::escapeTags(($_GET['order'] ?? '') ?: 'comment');
+	$order = Strings::escapeTags(($_GET['order'] ?? '') ?: 'activity');
 	$nets  =        $_GET['nets']  ?? '';
 
 	$allowedCids = [];
@@ -671,7 +671,7 @@ function networkThreadedView(App $a, $update, $parent)
 	}
 
 	// Normal conversation view
-	if ($order === 'arrival') {
+	if ($order === 'post') {
 		$ordering = '`received`';
 		$order_mode = 'received';
 	} else {
@@ -738,7 +738,7 @@ function networkThreadedView(App $a, $update, $parent)
 			if (Config::get("system", "like_no_comment")) {
 				$sql_extra4 .= " AND `item`.`gravity` IN (" . GRAVITY_PARENT . "," . GRAVITY_COMMENT . ")";
 			}
-			if ($order === 'arrival') {
+			if ($order === 'post') {
 				// Only show toplevel posts when updating posts in this order mode
 				$sql_extra4 .= " AND `item`.`id` = `item`.`parent`";
 			}
@@ -913,9 +913,9 @@ function network_tabs(App $a)
 	// item filter tabs
 	/// @TODO fix this logic, reduce duplication
 	/// $a->page['content'] .= '<div class="tabs-wrapper">';
-	list($no_active, $all_active, $arrival_active, $conv_active, $new_active, $starred_active, $bookmarked_active) = network_query_get_sel_tab($a);
+	list($no_active, $all_active, $post_active, $conv_active, $new_active, $starred_active, $bookmarked_active) = network_query_get_sel_tab($a);
 
-	// if no tabs are selected, defaults to comments
+	// if no tabs are selected, defaults to activitys
 	if ($no_active == 'active') {
 		$all_active = 'active';
 	}
@@ -925,19 +925,19 @@ function network_tabs(App $a)
 	// tabs
 	$tabs = [
 		[
-			'label'	=> L10n::t('Commented Order'),
-			'url'	=> str_replace('/new', '', $cmd) . '?order=comment' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
+			'label'	=> L10n::t('Latest Activities'),
+			'url'	=> str_replace('/new', '', $cmd) . '?order=activity' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
 			'sel'	=> $all_active,
-			'title'	=> L10n::t('Sort by Comment Date'),
-			'id'	=> 'commented-order-tab',
+			'title'	=> L10n::t('Sort by activity Date'),
+			'id'	=> 'activity-order-tab',
 			'accesskey' => 'e',
 		],
 		[
-			'label'	=> L10n::t('Arrival Order'),
-			'url'	=> str_replace('/new', '', $cmd) . '?order=arrival' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
-			'sel'	=> $arrival_active,
-			'title'	=> L10n::t('Sort by arrival date'),
-			'id'	=> 'arrival-order-tab',
+			'label'	=> L10n::t('Latest Posts'),
+			'url'	=> str_replace('/new', '', $cmd) . '?order=post' . (!empty($_GET['cid']) ? '&cid=' . $_GET['cid'] : ''),
+			'sel'	=> $post_active,
+			'title'	=> L10n::t('Sort by post date'),
+			'id'	=> 'post-order-tab',
 			'accesskey' => 't',
 		],
 	];
@@ -985,7 +985,7 @@ function network_tabs(App $a)
 	// save selected tab, but only if not in file mode
 	if (empty($_GET['file'])) {
 		PConfig::set(local_user(), 'network.view', 'tab.selected', [
-			$all_active, $arrival_active, $conv_active, $new_active, $starred_active, $bookmarked_active
+			$all_active, $post_active, $conv_active, $new_active, $starred_active, $bookmarked_active
 		]);
 	}
 
@@ -86,20 +86,20 @@ function network_init(App $a)
 		if ($remember_tab) {
 			// redirect if current selected tab is '/network' and
-			// last selected tab is _not_ '/network?order=comment'.
+			// last selected tab is _not_ '/network?order=activity'.
 			// and this isn't a date query
 
